Weenect - API to Weenect tracker server
SYNOPSIS
use Weenect;
my $user = Weenect::API->new;
$user->login( "me@example.com", "mypassword" );
my $trackers = $user->get_trackers;
foreach my $tracker ( $trackers->items->@* ) {
printf("Tracker %s [%d%s]\n", $tracker->name, $tracker->id,
$tracker->active ? "" : ",inactive" );
}
DESCRIPTION
Weenect makes GPS trackers for cats and dogs. The trackers communicate positions via GSM to the Weenect servers, and with the Weenect app or web interface you can see where your pet is.
This package facilitates connecting to the Weenect server and fetching some user and tracker data.
See the programs in the scripts directory for examples.
DISCLAIMER
Weenect doesn't want to disclose their API, so I needed to reverse engineer most of it.
LICENSE
Copyright (C) 2026, Johan Vromans
This module is free software. You can redistribute it and/or modify it under the terms of the Artistic License 2.0.
This program is distributed in the hope that it will be useful, but without any warranty; without even the implied warranty of merchantability or fitness for a particular purpose.